@@ -20,6 +20,8 @@
  */
 
 #include <vector>
+#include <unistd.h>
+#include <getopt.h>
 #include <vdr/remote.h>
 #include <FonbookManager.h>
 #include <Listener.h>
@@ -29,7 +31,7 @@
 #include "notifyosd.h"
 #include "menu.h"
 
-static const char *VERSION        = "1.3.3";
+static const char *VERSION        = "1.3.9";
 static const char *DESCRIPTION    = trNOOP("Fritz Plugin for AVM Fritz!Box");
 static const char *MAINMENUENTRY  = trNOOP("Fritz!Box");
 
@@ -40,6 +42,7 @@ cPluginFritzbox::cPluginFritzbox(void)
 	// DON'T DO ANYTHING ELSE THAT MAY HAVE SIDE EFFECTS, REQUIRE GLOBAL
 	// VDR OBJECTS TO EXIST OR PRODUCE ANY OUTPUT!
 	event = NULL;
+	logPersonalInfo = false;
 }
 
 cPluginFritzbox::~cPluginFritzbox()
@@ -61,13 +64,37 @@ const char *cPluginFritzbox::Description(void)
 const char *cPluginFritzbox::CommandLineHelp(void)
 {
 	// Return a string that describes all known command line options.
-	return NULL;
+	return "  -p,     --log-personal-info   log personal information (e.g. passwords, phone numbers, ...)\n"
+	       "  -c cmd, --on-call=cmd         call cmd on incoming or outgoing call events (see README)\n";
 }
 
 bool cPluginFritzbox::ProcessArgs(int argc, char *argv[])
 {
 	// Implement command line argument processing here if applicable.
-	return true;
+    static struct option long_options[] = {
+            { "log-personal-info", no_argument,       NULL, 'p' },
+            { "on-call",           required_argument, NULL, 'c' },
+            { NULL }
+    };
+
+    int c;
+    while ((c = getopt_long(argc, argv, "pc:", long_options, NULL)) != -1) {
+    switch (c) {
+        case 'p':
+				logPersonalInfo = true;
+				DBG("Logging personal information requested");
+                break;
+        case 'c':
+        		onCallCmd = optarg;
+        		DBG("User defined command " << onCallCmd << " registered");
+        		break;
+        default:
+                ERR("unknown command line option" << (char)c);
+                return false;
+        }
+    }
+
+    return true;
 }
 
 bool cPluginFritzbox::Initialize(void)
@@ -79,14 +106,14 @@ bool cPluginFritzbox::Initialize(void)
 
 bool cPluginFritzbox::Start(void)
 {
-	// first enable loggin to syslog
+	// first enable logging to syslog
 	dlog = new cLogStream(cLogBuf::DEBUG);
 	elog = new cLogStream(cLogBuf::ERROR);
 	ilog = new cLogStream(cLogBuf::INFO);
 	// use logging objects with libfritz++
 	fritz::Config::SetupLogging(dlog, ilog, elog);
 
-	event = new cFritzEventHandler();
+	event = new cFritzEventHandler(onCallCmd);
 	// start new thread for plugin initialization (may take some time)
 	cThread::Start();
 	return true;
@@ -100,9 +127,7 @@ void cPluginFritzbox::Stop(void)
 	SetupStore("CountryCode",         fritzboxConfig.countryCode.c_str());
 	SetupStore("RegionCode",          fritzboxConfig.regionCode.c_str());
 	// Stop any background activities the plugin shall perform.
-	fritz::Listener::DeleteListener();
-	fritz::CallList::DeleteCallList();
-	fritz::FonbookManager::DeleteFonbookManager();
+	fritz::Config::Shutdown();
 	if (event)
 		delete event;
 	if (dlog)
@@ -121,9 +146,14 @@ void cPluginFritzbox::Housekeeping(void)
 void cPluginFritzbox::MainThreadHook(void)
 {
 	if (!fritzboxConfig.useNotifyOsd && event) {
-		fritz::sCallInfo *callInfo = event->GetCallInfo();
-		if (callInfo)
-			Skins.Message(mtInfo, event->ComposeCallMessage().c_str());
+		std::vector<int> ids = event->GetPendingCallIds();
+		for (std::vector<int>::iterator it = ids.begin(); it < ids.end(); it++) {
+			fritz::sCallInfo callInfo = event->GetCallInfo(*it);
+			if (callInfo.localNumber.length() > 0) {
+				Skins.Message(mtInfo, event->ComposeCallMessage(*it).c_str());
+				event->NotificationDone(*it);
+			}
+		}
 	}
 }
 
@@ -154,14 +184,14 @@ const char *cPluginFritzbox::MainMenuEntry(void)
 
 cOsdObject *cPluginFritzbox::MainMenuAction(void)
 {
-	if (event && event->GetCallInfo()) {
+	if (event && event->GetPendingCallIds().size() && !cNotifyOsd::isOpen()) {
 		// called by cRemote::CallPlugin
 		return new cNotifyOsd(event);
 	}
 	else
 		// called by the user
 		if (this->Running()) {
-			Skins.Message(mtError, tr("This phonebook is not yet available."));
+			Skins.Message(mtError, tr("Data not yet available."));
 			return NULL;
 		}
 		else
@@ -201,9 +231,8 @@ cString cPluginFritzbox::SVDRPCommand(const char *Command, const char *Option, i
 void cPluginFritzbox::Action() {
 
 	// init libfritz++
-	fritz::Config::Setup(fritzboxConfig.url, fritzboxConfig.password,
-			&fritzboxConfig.locationSettingsDetected,
-			&fritzboxConfig.countryCode, &fritzboxConfig.regionCode);
+	fritz::Config::Setup(fritzboxConfig.url, fritzboxConfig.password, logPersonalInfo);
+	fritz::Config::Init(&fritzboxConfig.locationSettingsDetected, &fritzboxConfig.countryCode, &fritzboxConfig.regionCode);
 	fritz::Config::SetupConfigDir(fritzboxConfig.configDir);
 	fritz::Config::SetupMsnFilter(fritzboxConfig.msn);
 	fritz::FonbookManager::CreateFonbookManager(fritzboxConfig.selectedFonbookIDs, fritzboxConfig.activeFonbookID);
@@ -212,11 +241,9 @@ void cPluginFritzbox::Action() {
 	// Create FritzListener only if needed
 	if (fritzboxConfig.showNumber || fritzboxConfig.pauseOnCall || fritzboxConfig.muteOnCall)
 		fritz::Listener::CreateListener(event);
-	else
-		fritz::Listener::DeleteListener();
 }
 
-std::string cPluginFritzbox::FonbookEntryToName(const fritz::FonbookEntry::eType type) {
+std::string cPluginFritzbox::FonbookEntryTypeToName(const fritz::FonbookEntry::eType type) {
 	switch (type) {
 	case fritz::FonbookEntry::TYPE_HOME:
 		//TRANSLATORS: telephonebook number type: this is a one char abbreviation for "home"
